@@ -19,7 +19,7 @@ class ModelStorage(BaseStorage):
         return URIType.MODEL
 
     @property
-    def src_dir(self):
+    def src_dir(self) -> Path:
         return self.snapshot_workdir / "src"
 
     @property
@@ -33,7 +33,3 @@ class ModelStorage(BaseStorage):
     @property
     def snapshot_workdir(self) -> Path:
         return self._get_snapshot_workdir_for_bundle()
-
-    @property
-    def recover_snapshot_workdir(self) -> Path:
-        return self._get_recover_snapshot_workdir_for_bundle()
