@@ -52,3 +52,15 @@ class PythonEnvironmentError(Exception):
 
 class FieldTypeOrValueError(Exception):
     pass
+
+
+class ParameterError(Exception):
+    pass
+
+
+class ExclusiveArgsError(Exception):
+    pass
+
+
+class InvalidObjectName(Exception):
+    pass
